require "spec_helper.rb"
require 'treetop'
require 'SweetTea/nodes'
Treetop.load(File.expand_path("../../lib/SweetTea/grammar", __FILE__))

describe "SweetTea grammer" do
  subject { SweetTeaParser.new }
  context "class" do
    it "should recognise both ways of creating a class" do
      subject.parse("class-> ClassName <-class").should_not be_nil
      subject.parse("c-> ClassName <-c").should_not be_nil
    end
    
    it "should allow content" do
      subject.parse(
        <<-CODE
          class-> MyClass
            function-> myFunction <-function
            variable-> var2 = "value"
          <-class
        CODE
        ).should_not be_nil
    end
  end
  
  context "function" do
    it "should recognise all three ways of creating a function" do
      subject.parse("function-> functionName <-function").should_not be_nil
      subject.parse("func-> functionName <-func").should_not be_nil
      subject.parse("f-> functionName <-f").should_not be_nil
    end
    
    it "should allow arguments" do
      subject.parse("f-> functionName arg1 arg2 arg3 <-function").should_not be_nil
    end
    
    it "should allow content" do
      subject.parse(
        <<-CODE
          function-> myFunction
            variable-> myVar = "Hello World"
          <-function
        CODE
        ).should_not be_nil
    end
  end
  
  context "variable" do
    it "should recognise all three ways of creating a variable" do
      subject.parse("variable-> variableName = \"value\"").should_not be_nil
      subject.parse("var-> variableName = \"value\"").should_not be_nil
      subject.parse("v-> variableName = \"value\"").should_not be_nil
    end
    
    it "shouldn't require a value to be created" do
      subject.parse("variable-> variableName").should_not be_nil
    end
  end
end