require "spec_helper.rb"
require "SweetTea/parser"
base_path = File.expand_path(File.dirname(__FILE__))

code = { stea: {}, js: {} }
Dir["#{base_path}/expected_js/*.js"].each do |path|
  contents = File.read(path).split("\n----\n")
  refName = File.basename(path, ".js").to_sym
  code[:stea][refName] = contents[0]
  code[:js][refName] = contents[1]
end

describe "SweetTea parser" do
  subject { SweetTea::Parser.new }
  context "class" do
    it "should generate the correct javascript for an empty class" do
      subject.parse(code[:stea][:class_empty]).should == code[:js][:class_empty]
    end
    
    it "should transfer content of 'init' function to class constructor" do
      subject.parse(code[:stea][:class_init]).should == code[:js][:class_init]
    end
    
    it "should transfer the args of 'init' function to class constructor" do
      subject.parse(code[:stea][:class_init_args]).should == code[:js][:class_init_args]
    end
  end
  
  context "function" do
    it "should generate the correct javascript for an empty function" do
      subject.parse(code[:stea][:func_empty]).should == code[:js][:func_empty]
    end
    
    it "should generate the correct javascript for a function with args" do
      subject.parse(code[:stea][:func_args]).should == code[:js][:func_args]
    end
    
    it "should generate the correct type of function for a class method" do
      subject.parse(code[:stea][:func_class]).should == code[:js][:func_class]
    end
    
    it "doesn't generate class function within class function" do
      subject.parse(code[:stea][:func_gen_correct_type]).should == code[:js][:func_gen_correct_type]
    end
  end
  
  context "variable" do
    it "should generate the correct javascript for a initialised variable" do
      subject.parse(code[:stea][:var_w_value]).should == code[:js][:var_w_value]
    end
    
    it "should generate the correct javascript for an empty variable" do
      subject.parse(code[:stea][:var_empty]).should == code[:js][:var_empty]
    end
    
    it "should generate the correct type of variable for a class method" do
      subject.parse(code[:stea][:var_class]).should == code[:js][:var_class]
    end
    
    it "doesn't generate class variable within class function" do
      subject.parse(code[:stea][:var_gen_correct_type]).should == code[:js][:var_gen_correct_type]
    end
  end
end